Here is an extended example that involves more text than what can fit inside a
single paragraph of text. This is to ensure that when the translator encounters
mutliple paragraphs - unlike the code blocks it does not split the paragraph
into multiple cells.

Instead this should be combined into a single cell with the appropriate spacing
between the lines so that they are formatted accordingly.
